@@ -5,12 +5,11 @@ from mikro.datalayer import DataLayer
 from mikro.rath import MikroRath
 
 
-@koilable(add_connectors=True)
 class Mikro(Composition):
-    """ The Mikro Composition
-    
+    """The Mikro Composition
+
     This composition provides a datalayer and a rath for interacting with the
-    mikro api.
+    mikro api and beyond
 
     You shouldn't need to create this directly, instead use the builder functions
     to generate a new instance of this composition.
@@ -29,7 +28,6 @@ class Mikro(Composition):
     ```
     """
 
-
     datalayer: DataLayer
     rath: MikroRath = Field(default_factory=MikroRath)
 
