@@ -21,9 +21,8 @@ except ImportError:
 # Check if rekuest is installed
 # If it is, register the structures with the default structure registry
 if rekuest:
-    from rekuest.structures.default import get_default_structure_registry
+    from rekuest.structures.default import get_default_structure_registry, Scope
     from rekuest.widgets import SearchWidget
-    from rekuest.widgets import CustomReturnWidget
     from mikro.api.schema import *
 
     structure_reg = get_default_structure_registry()
@@ -31,6 +30,7 @@ if rekuest:
         RepresentationFragment,
         identifier="@mikro/representation",
         expand=aexpand_representation,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_representationQuery.Meta.document, ward="mikro"
         ),
@@ -39,13 +39,28 @@ if rekuest:
         MetricFragment,
         identifier="@mikro/metric",
         expand=aexpand_metric,
+        scope=Scope.GLOBAL,
+        default_widget=None,
+    )
+    structure_reg.register_as_structure(
+        ChannelFragment,
+        identifier="@mikro/channel",
+        expand=aget_channel,
+        scope=Scope.GLOBAL,
+        default_widget=None,
+    )
+    structure_reg.register_as_structure(
+        DimensionMapFragment,
+        identifier="@mikro/dimensionmap",
+        expand=aget_dimension_map,
+        scope=Scope.GLOBAL,
         default_widget=None,
-        default_returnwidget=CustomReturnWidget(hook="metric"),
     )
     structure_reg.register_as_structure(
         SampleFragment,
         identifier="@mikro/sample",
         expand=aexpand_sample,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_sampleQuery.Meta.document, ward="mikro"
         ),
@@ -54,6 +69,7 @@ if rekuest:
         TableFragment,
         identifier="@mikro/table",
         expand=aexpand_table,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_tablesQuery.Meta.document, ward="mikro"
         ),
@@ -62,6 +78,7 @@ if rekuest:
         ExperimentFragment,
         identifier="@mikro/experiment",
         expand=aexpand_experiment,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_experimentQuery.Meta.document, ward="mikro"
         ),
@@ -70,6 +87,7 @@ if rekuest:
         ThumbnailFragment,
         identifier="@mikro/thumbnail",
         expand=aexpand_thumbnail,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_thumbnailsQuery.Meta.document, ward="mikro"
         ),
@@ -78,6 +96,7 @@ if rekuest:
         OmeroFileFragment,
         identifier="@mikro/omerofile",
         expand=aexpand_omerofile,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_omerofileQuery.Meta.document, ward="mikro"
         ),
@@ -86,12 +105,14 @@ if rekuest:
         ROIFragment,
         identifier="@mikro/roi",
         expand=aexpand_roi,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(query=Search_roisQuery.Meta.document, ward="mikro"),
     )
     structure_reg.register_as_structure(
         FeatureFragment,
         identifier="@mikro/feature",
         expand=aexpand_feature,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_featuresQuery.Meta.document, ward="mikro"
         ),
@@ -100,13 +121,24 @@ if rekuest:
         LabelFragment,
         identifier="@mikro/label",
         expand=aexpand_label,
+        scope=Scope.GLOBAL,
         default_widget=SearchWidget(
             query=Search_labelsQuery.Meta.document, ward="mikro"
         ),
     )
+    structure_reg.register_as_structure(
+        VideoFragment,
+        identifier="@mikro/video",
+        scope=Scope.GLOBAL,
+        expand=aget_video,
+        default_widget=SearchWidget(
+            query=Search_videosQuery.Meta.document, ward="mikro"
+        ),
+    )
     structure_reg.register_as_structure(
         PositionFragment,
         identifier="@mikro/position",
+        scope=Scope.GLOBAL,
         expand=aexpand_position,
         default_widget=SearchWidget(
             query=Search_positionsQuery.Meta.document, ward="mikro"
@@ -115,6 +147,7 @@ if rekuest:
     structure_reg.register_as_structure(
         StageFragment,
         identifier="@mikro/stage",
+        scope=Scope.GLOBAL,
         expand=aexpand_stage,
         default_widget=SearchWidget(
             query=Search_stagesQuery.Meta.document, ward="mikro"
@@ -123,6 +156,7 @@ if rekuest:
     structure_reg.register_as_structure(
         DatasetFragment,
         identifier="@mikro/dataset",
+        scope=Scope.GLOBAL,
         expand=aexpand_dataset,
         default_widget=SearchWidget(
             query=Search_datasetsQuery.Meta.document, ward="mikro"
@@ -131,6 +165,7 @@ if rekuest:
     structure_reg.register_as_structure(
         ObjectiveFragment,
         identifier="@mikro/objective",
+        scope=Scope.GLOBAL,
         expand=aexpand_objective,
         default_widget=SearchWidget(
             query=Search_objectivesQuery.Meta.document, ward="mikro"
@@ -139,6 +174,7 @@ if rekuest:
     structure_reg.register_as_structure(
         ModelFragment,
         identifier="@mikro/model",
+        scope=Scope.GLOBAL,
         expand=aexpand_model,
         default_widget=SearchWidget(
             query=Search_modelsQuery.Meta.document, ward="mikro"
@@ -147,6 +183,7 @@ if rekuest:
     structure_reg.register_as_structure(
         ContextFragment,
         identifier="@mikro/context",
+        scope=Scope.GLOBAL,
         expand=aexpand_context,
         default_widget=SearchWidget(
             query=Search_contextsQuery.Meta.document, ward="mikro"
@@ -155,9 +192,9 @@ if rekuest:
     structure_reg.register_as_structure(
         LinkFragment,
         identifier="@mikro/link",
+        scope=Scope.GLOBAL,
         expand=aexpand_link,
         default_widget=SearchWidget(
             query=Search_linksQuery.Meta.document, ward="mikro"
         ),
     )
-
